Index: src/arm/codegen-arm.h |
=================================================================== |
--- src/arm/codegen-arm.h (revision 4568) |
+++ src/arm/codegen-arm.h (working copy) |
@@ -312,10 +312,20 @@ |
// Store the value on top of the stack to a slot. |
void StoreToSlot(Slot* slot, InitState init_state); |
- // Load a named property, leaving it in r0. The receiver is passed on the |
+ // Support for compiling assignment expressions. |
+ void EmitSlotAssignment(Assignment* node); |
+ void EmitNamedPropertyAssignment(Assignment* node); |
+ void EmitKeyedPropertyAssignment(Assignment* node); |
+ |
+ // Load a named property, returning it in r0. The receiver is passed on the |
// stack, and remains there. |
void EmitNamedLoad(Handle<String> name, bool is_contextual); |
+ // Store to a named property. If the store is contextual, value is passed on |
+ // the frame and consumed. Otherwise, receiver and value are passed on the |
+ // frame and consumed. The result is returned in r0. |
+ void EmitNamedStore(Handle<String> name, bool is_contextual); |
+ |
// Load a keyed property, leaving it in r0. The receiver and key are |
// passed on the stack, and remain there. |
void EmitKeyedLoad(); |